@@ -26,6 +26,7 @@
 #include <libgnomecups/gnome-cups-queue.h>
 #include <libgnomecups/gnome-cups-ui-print.h>
 #include <libgnomecups/gnome-cups-ui-util.h>
+#include <libgnomecups/gnome-cups-permission.h>
 
 #include "printer-properties.h"
 
@@ -202,16 +203,16 @@ get_menu_sensitivities (GladeXML *xml,
 	selection = gtk_tree_view_get_selection (view);
 	if (pause) {
 		*pause = FALSE;
-		gtk_tree_selection_selected_foreach (selection,
-						     selection_has_running_cb,
-						     pause);
+		if (gnome_cups_can_admin ())
+			gtk_tree_selection_selected_foreach (selection,
+				selection_has_running_cb, pause);
 	}
 
 	if (resume) {
 		*resume = FALSE;
-		gtk_tree_selection_selected_foreach (selection,
-						     selection_has_paused_cb,
-						     resume);
+		if (gnome_cups_can_admin ())
+			gtk_tree_selection_selected_foreach (selection,
+				selection_has_paused_cb, resume);
 	}
 
 	if (cancel) {
