@@ -1,5 +1,5 @@
-#ifndef GNOME_CUPS_UI_INIT
-#define GNOME_CUPS_UI_INIT
+#ifndef GNOME_CUPS_UI_PRINT
+#define GNOME_CUPS_UI_PRINT
 
 #include <glib/gmacros.h>
 #include <libgnomecups/gnome-cups-printer.h>
